#include <unordered_set>
#include <algorithm>
#include <iostream>
#include <fstream>
#include <cassert>
#include <vector>
#include <cmath>

typedef long long llong;
const int MAXN = 200000 + 10;
const int MAX_NUM = 1e6;

int n;
int a[MAXN];
int b[MAXN];
int minN, maxN, ans;

inline void placeBeautiful(int idx) // min(a[i], b[i]) >= max(a[i + 1], b[i + 1])
{
    int max = std::max(a[idx + 1], b[idx + 1]);
    do
    {
        a[idx] = max + rand()%2;
        b[idx] = max + rand()%2;
    } while (a[idx] == b[idx]);
}

inline void placeGood(int idx) // a[i] >= a[i + 1], b[i] >= b[i + 1]
{
    do
    {
        a[idx] = a[idx + 1] + rand()%2;
        b[idx] = b[idx + 1] + rand()%2;
    } while ((a[idx] >= b[idx + 1] && b[idx] >= a[idx + 1]) || a[idx] == b[idx]);
}

inline void placeBad(int idx) // a[i] >= b[i + 1], a[i] >= b[i + 1], a[i] < a[i + 1] or b[i] < b[i + 1]
{
    do
    {
        a[idx] = b[idx + 1] + rand()%2;
        b[idx] = a[idx + 1] + rand()%2;
    } while ((a[idx] >= a[idx + 1] && b[idx] >= b[idx + 1]) || a[idx] == b[idx]);
}

inline void placeBad2(int idx) // a[i] >= b[i + 1], a[i] >= b[i + 1], a[i] < a[i + 1] or b[i] < b[i + 1]
{
    do
    {
        a[idx] = b[idx - 1] - rand()%2;
        b[idx] = a[idx - 1] - rand()%2;
    } while ((a[idx] <= a[idx - 1] && b[idx] <= b[idx - 1]) || a[idx] == b[idx]);
}

inline void placeImpossible(int idx) // max(a[i], b[i]) < max(a[i + 1], b[i + 1]) or min(a[i], b[i]) < min(a[i + 1], b[i + 1])
{
    do
    {
        a[idx] = b[idx + 1] - rand()%2;
        b[idx] = a[idx + 1] - rand()%2;
    } while (!(std::max(a[idx], b[idx]) < std::max(a[idx + 1], b[idx + 1]) || std::min(a[idx], b[idx]) < std::min(a[idx + 1], b[idx + 1])));
}

std::vector <int> splitNumber(int number, int cntGroups)
{
    std::vector <int> vals, groups;

    vals.push_back(0);
    vals.push_back(number);
    for (int i = 1 ; i < cntGroups ; ++i)
    {
        vals.push_back(rand()%(number + 1));
    }

    std::sort(vals.begin(), vals.end());
    for (int i = 1 ; i <= cntGroups ; ++i)
    {
        groups.push_back(vals[i] - vals[i - 1]);
    }

    return groups;
}

int decompressed[MAXN];
std::unordered_set <int> cnt;
std::vector <int> splitNumberPositive(int number, int cntGroups)
{
    cnt.clear();
    std::vector <int> vals;
    std::vector <int> groups;

    vals.push_back(0);
    vals.push_back(number);
    cnt.insert(0);
    cnt.insert(number);

    for (int i = 1 ; i < cntGroups ; ++i)
    {
        int rnd;
        do rnd = rand()%(number + 1);
        while (cnt.count(rnd));
        vals.push_back(rnd);
        cnt.insert(rnd);
    }

    std::sort(vals.begin(), vals.end());
    for (int i = 1 ; i <= cntGroups ; ++i)
    {
        groups.push_back(vals[i] - vals[i - 1]);
    }

    return groups;
}

int who[MAXN];
bool willBeBad[MAXN];
bool impossible;
int main(int argc, char **argv)
{
    srand(time(nullptr));
    std::ifstream fin("constraints.txt");
    std::ofstream fout(argv[1]);
    fin >> minN >> maxN >> ans;
    for (int i = 1 ; i <= ans ; ++i)
    {
        fin >> who[i];
        willBeBad[who[i]] = true;
    }

    n = rand()%(maxN - minN + 1) + minN;
    if (ans == -1)
    {
        ans = rand()%(n / 2 + 1);
        impossible = true;
    }
    
    assert(ans <= n/2);

    int ptr = n;
    a[n + 1] = b[n + 1] = 1;
    for (int i = n ; i >= 1 ; --i)
    {
        std::cout << "here: " << i << '\n';
        int rnd = rand()%2;
        if (rnd == 0 && i != n) placeGood(i);
        else placeBeautiful(i);
    }

    for (int i = 1 ; i <= n ; ++i)
    {
        std::cout << a[i] << ' ' << b[i] << '\n';
    }

    for (int i = ans ; i >= 1 ; --i)
    {
        if (who[i] != n) placeBad(who[i]);
        else placeBad2(who[i]);
    }

    if (impossible)
    {
        int rnd = rand()%(n - 1) + 1;
        placeImpossible(rnd);
    }
    
    cnt.clear();
    for (int i = 1 ; i <= std::max(a[1], b[1]) ; ++i)
    {
        do decompressed[i] = rand()%MAX_NUM + 1;
        while (cnt.count(decompressed[i]));
        cnt.insert(decompressed[i]);
    }

    std::sort(decompressed + 1, decompressed + 1 + std::max(a[1], b[1]));
    for (int i = 1 ; i <= n ; ++i)
    {
        a[i] = decompressed[a[i]];
        b[i] = decompressed[b[i]];
    }

    fout << n << '\n';
    for (int i = 1 ; i <= n ; ++i)
    {
        fout << a[i] << ' ' << b[i] << '\n';
    }

    fout.close();
    fin.close();
    return 0;
}